import { jsx as _jsx, Fragment as _Fragment } from "react/jsx-runtime";
import { vitest } from 'vitest';
import { useState } from 'react';
import { fireEvent, render, screen } from '@testing-library/react';
import { Datagrid, } from './datagrid.component';
import DataGridTextCell from './text-cell.component';
vitest.mock('react-i18next', async () => {
    const originalModule = await vitest.importActual('react-i18next');
    return {
        ...originalModule,
        useTranslation: () => {
            return {
                t: (str) => str,
                i18n: {
                    changeLanguage: () => new Promise(() => { }),
                },
            };
        },
    };
});
const sampleColumns = [
    {
        id: 'name',
        cell: (name) => {
            return _jsx("span", { children: name });
        },
        label: 'Name',
    },
    {
        id: 'another-column',
        label: 'test',
        cell: () => _jsx(DataGridTextCell, {}),
    },
];
const DatagridTest = ({ columns, items, pageIndex, className, noResultLabel, }) => {
    const [pagination, setPagination] = useState({
        pageIndex,
        pageSize: 2,
    });
    const start = pagination.pageIndex * pagination.pageSize;
    const end = start + pagination.pageSize;
    return (_jsx(Datagrid, { columns: columns, items: items.slice(start, end), totalItems: items.length, pagination: pagination, sorting: { id: 'name', desc: false }, onPaginationChange: setPagination, onSortChange: () => { }, className: className || '', noResultLabel: noResultLabel }));
};
describe('Paginated datagrid component', () => {
    beforeAll(() => {
        // Mock attachInternals method for all instances of custom elements
        HTMLElement.prototype.attachInternals = vitest.fn(() => ({
            // Mock the properties or methods used from internals
            setValidity: vitest.fn(),
            states: new Set(),
        }));
    });
    it('should display the correct number of columns', async () => {
        const { container } = render(_jsx(DatagridTest, { columns: [
                {
                    id: 'a',
                    cell: () => _jsx(_Fragment, { children: "'a'" }),
                    label: 'a',
                },
                {
                    id: 'b',
                    cell: () => _jsx(_Fragment, { children: "'b'" }),
                    label: 'b',
                },
                {
                    id: 'c',
                    cell: () => _jsx(_Fragment, { children: "'c'" }),
                    label: 'c',
                },
            ], items: [], pageIndex: 0 }));
        expect(container.querySelectorAll('thead th').length).toBe(3);
    });
    it('should call sort function when clicking columns header', async () => {
        const handleSortChange = vitest.fn();
        const SortTest = () => {
            const [sorting, setSorting] = useState({ id: 'a', desc: true });
            return (_jsx(Datagrid, { columns: [
                    {
                        id: 'a',
                        cell: () => _jsx(_Fragment, { children: "'a'" }),
                        label: 'a',
                    },
                    {
                        id: 'b',
                        cell: () => _jsx(_Fragment, { children: "'b'" }),
                        label: 'b',
                    },
                ], items: [], totalItems: 0, pagination: { pageIndex: 0, pageSize: 1 }, sorting: sorting, manualSorting: true, onPaginationChange: () => { }, onSortChange: (c) => {
                    setSorting(c);
                    handleSortChange(c);
                } }));
        };
        render(_jsx(SortTest, {}));
        const headerA = screen.queryByTestId('header-a');
        expect(headerA).not.toBeNull();
        expect(handleSortChange).not.toHaveBeenCalled();
        fireEvent.click(headerA);
        expect(handleSortChange).toHaveBeenCalledWith({ id: 'a', desc: false });
        fireEvent.click(headerA);
        expect(handleSortChange).toHaveBeenCalledWith({ id: 'a', desc: true });
        fireEvent.click(headerA);
        expect(handleSortChange).toHaveBeenCalledWith({ id: 'a', desc: false });
        const headerB = screen.queryByTestId('header-b');
        fireEvent.click(headerB);
        expect(handleSortChange).toHaveBeenCalledWith({ id: 'b', desc: false });
    });
    it('should display first page of items', async () => {
        const { container } = render(_jsx(DatagridTest, { columns: sampleColumns, items: ['foo', 'bar', 'hello'], pageIndex: 0 }));
        expect(screen.queryByText('foo')).not.toBeNull();
        expect(screen.queryByText('bar')).not.toBeNull();
        expect(screen.queryByText('hello')).toBeNull();
        expect(container.querySelectorAll('thead tr').length).toBe(1);
        expect(container.querySelectorAll('tbody tr').length).toBe(2);
    });
    it('should display second page of items', async () => {
        const { container } = render(_jsx(DatagridTest, { columns: sampleColumns, items: ['foo', 'bar', 'hello'], pageIndex: 1 }));
        expect(screen.queryByText('foo')).toBeNull();
        expect(screen.queryByText('bar')).toBeNull();
        expect(screen.queryByText('hello')).not.toBeNull();
        expect(container.querySelectorAll('thead tr').length).toBe(1);
        expect(container.querySelectorAll('tbody tr').length).toBe(1);
    });
    it('should display a message if there are no items', async () => {
        const { container } = render(_jsx(DatagridTest, { columns: sampleColumns, items: [], pageIndex: 0 }));
        expect(screen.queryByText('common_pagination_no_results')).not.toBeNull();
        expect(container.querySelectorAll('thead tr').length).toBe(1);
        expect(container.querySelectorAll('tbody tr').length).toBe(1);
    });
    it('should display a custom message if there are no items and we pass a custom message', async () => {
        render(_jsx(DatagridTest, { columns: sampleColumns, items: [], pageIndex: 0, noResultLabel: "Test no result" }));
        expect(screen.queryByText('Test no result')).not.toBeNull();
    });
});
it('should disable overflow of table', async () => {
    const { container } = render(_jsx(DatagridTest, { columns: sampleColumns, items: [], pageIndex: 0, className: 'overflow-hidden' }));
    expect(container.querySelectorAll('.overflow-hidden').length).toBe(1);
});
